/* Tabela PRODUTOSEG: */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes
na tabela PRODUTOSEG */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela Item do PRODUTOSEG,
utilizando a tabela Geral de Logs de Operaes */


IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_GER_PRODUTOSEG' AND
                 TYPE   = 'TR' 	              AND
	              U.UID  = O.UID                AND
	              U.NAME = USER)
DROP TRIGGER LOG_GER_PRODUTOSEG
GO


CREATE  TRIGGER LOG_GER_PRODUTOSEG
ON PRODUTOSEG
FOR INSERT, UPDATE, DELETE
AS
   DECLARE  @V_USUARIO      VARCHAR(40);
   DECLARE  @V_TIPO         VARCHAR(1);
   DECLARE  @V_ITPESQ       VARCHAR(40);
   DECLARE  @V_DESC         VARCHAR(300);
   DECLARE  @V_DTOPER       DATETIME;

/*VARIVEIS DO CURSOR C_CURSOR*/


   DECLARE  @V_ID_COMANDO         VARCHAR(1);
   DECLARE  @V_CDSEGMER_OLD       VARCHAR(5);
   DECLARE  @V_IDPROSEGATIV_OLD   VARCHAR(20);
   DECLARE  @V_CDPRODUTO_OLD      VARCHAR(10);
   DECLARE  @V_CDSEGMER_NEW       VARCHAR(5);
   DECLARE  @V_IDPROSEGATIV_NEW   VARCHAR(20);
   DECLARE  @V_CDPRODUTO_NEW      VARCHAR(10);


BEGIN
   SET   @V_TIPO = '0';
   SET   @V_DESC = '';

   EXEC NMUSUARIO @V_USUARIO;
   SET @V_USUARIO = ISNULL(@V_USUARIO, '');

   DECLARE C_CURSOR_PRODSEG CURSOR FOR
   SELECT
      'D' IDCOMANDO,

      CDSEGMER,
      CDPRODUTO,
      IDPROSEGATIV,
      NULL,
      NULL,
      NULL
   FROM
      DELETED
   WHERE
      (CDSEGMER+ CDPRODUTO) NOT IN (SELECT CDSEGMER+ CDPRODUTO FROM INSERTED)
   UNION ALL

   SELECT
      'U' IDCOMANDO,

      DELETED.CDSEGMER,
      DELETED.CDPRODUTO,
      DELETED.IDPROSEGATIV,
      INSERTED.CDSEGMER,
      INSERTED.CDPRODUTO,
      INSERTED.IDPROSEGATIV
   FROM
      INSERTED,
      DELETED
   WHERE
      INSERTED.CDSEGMER  = DELETED.CDSEGMER  AND
      INSERTED.CDPRODUTO = DELETED.CDPRODUTO
   UNION ALL

   SELECT
      'I' IDCOMANDO,
      NULL,
      NULL,
      NULL,
      CDSEGMER,
      CDPRODUTO,
      IDPROSEGATIV
   FROM
      INSERTED
   WHERE
      (CDSEGMER+ CDPRODUTO)  NOT IN (SELECT CDSEGMER+ CDPRODUTO FROM DELETED);

   OPEN C_CURSOR_PRODSEG;
   FETCH NEXT FROM C_CURSOR_PRODSEG INTO @V_ID_COMANDO,
				                     	     @V_CDSEGMER_OLD,
                                         @V_CDPRODUTO_OLD,
                                         @V_IDPROSEGATIV_OLD,
                                         @V_CDSEGMER_NEW,
                                         @V_CDPRODUTO_NEW,
                                         @V_IDPROSEGATIV_NEW;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      SET   @V_DESC = '';
      IF @V_ID_COMANDO= 'D' /*DELETING*/ BEGIN
         SET @V_TIPO         = '3';
         SET @V_ITPESQ       = @V_CDSEGMER_OLD + @V_CDPRODUTO_OLD;
         IF @V_CDPRODUTO_OLD IS NOT NULL BEGIN
            SET  @V_DESC = @V_DESC +'Produto=' + @V_CDPRODUTO_OLD;
         END;
         IF @V_CDSEGMER_OLD IS NOT NULL BEGIN
            SET  @V_DESC = @V_DESC + ' CodSegMerc=' + @V_CDSEGMER_OLD;
         END;
         IF @V_IDPROSEGATIV_OLD IS NOT NULL BEGIN
            SET  @V_DESC = @V_DESC + ' Ativo=' + @V_IDPROSEGATIV_OLD;
         END;
      END
      ELSE BEGIN
         IF @V_ID_COMANDO= 'U' /*UPDATING*/ BEGIN
            IF (@V_CDPRODUTO_OLD     <> @V_CDPRODUTO_NEW)    OR
               (@V_CDSEGMER_OLD      <> @V_CDSEGMER_NEW)     OR
               (ISNULL(@V_IDPROSEGATIV_OLD,'!')  <> ISNULL(@V_IDPROSEGATIV_NEW,'!')) BEGIN
               SET  @V_TIPO         = '2';
               SET @V_ITPESQ        = @V_CDSEGMER_OLD + @V_CDPRODUTO_OLD;
            END;
         END
         ELSE BEGIN
            SET @V_TIPO         = '1';
            SET @V_ITPESQ       = @V_CDSEGMER_NEW + @V_CDPRODUTO_NEW;
         END;
         IF @V_CDPRODUTO_NEW IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'CodProduto=' + @V_CDPRODUTO_NEW;
         END;
         IF @V_CDSEGMER_NEW IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + ' codSegMerc=' + @V_CDSEGMER_NEW;
         END;
         IF ISNULL(@V_IDPROSEGATIV_NEW,'!') <> ISNULL(@V_IDPROSEGATIV_OLD,'!') BEGIN
            SET @V_DESC = @V_DESC + ' Ativo=' + @V_IDPROSEGATIV_NEW;
         END;
      END;
      IF @V_TIPO <> '0' BEGIN
         IF NOT @V_DESC IS NULL BEGIN
            IF NOT @V_USUARIO IS NULL BEGIN
               SET @V_DTOPER = GETDATE();
               INSERT INTO LOGOPERA
                 (NMTABELA,   DTOPERACAO, NMRESPOPER,
                 IDTIPOOPER, CDPESQITEM, DSOPERACAO)
            VALUES
               ('PRODUTOSEG',  @V_DTOPER, @V_USUARIO,
                @V_TIPO,      @V_ITPESQ, @V_DESC);
            END;
         END;
      END;
      FETCH NEXT FROM C_CURSOR_PRODSEG INTO @V_ID_COMANDO,
                                            @V_CDSEGMER_OLD,
                                            @V_CDPRODUTO_OLD,
                                            @V_IDPROSEGATIV_OLD,
                                            @V_CDSEGMER_NEW,
                                            @V_CDPRODUTO_NEW,
                                            @V_IDPROSEGATIV_NEW;
   END;
   CLOSE      C_CURSOR_PRODSEG;
   DEALLOCATE C_CURSOR_PRODSEG;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_GER_PRODUTOSEG','4.11.105';
GO

